@@ -56,8 +56,8 @@ class QDate;
 class QFile;
 
 // Local class prototypes
-// class AmountBox; // Warning: Might be replaced with QTimeEdit
-class Daydatedit;
+class ASTimeEdit;
+class Daydatedit; // Might be replaced with ASTimeEdit throughout
 class TiTable;
 class Preferences;
 class Prefpanel;
@@ -204,6 +204,7 @@ public:
     QAction     *m_pRefreshact,   *m_pCutact;
     QAction     *m_pCopyact,      *m_pPasteact;
     QAction     *m_pSyncact,      *m_pPrefsact;
+    QAction     *m_pReportact;
 
     // Table, cells, and entries in package layout
     TiTable     *m_pMaintable;
@@ -220,8 +221,8 @@ public:
     Daydatedit  *m_pDateedit;           // Control to edit date
     QTimeEdit   *m_pStarttime;          // Control to edit start time
     QTimeEdit   *m_pEndtime;            // Control to edit finish time
-    QTimeEdit   *m_pAmount;             // Control to edit total time
-//    AmountBox   *m_pAmount;             // Control to edit total time
+//    QTimeEdit   *m_pAmount;             // Control to edit total time
+    ASTimeEdit  *m_pAmount;             // Control to edit total time
     QComboBox   *m_pTasks;              // Control to choose a task
     QLineEdit   *m_pRemark;             // Control to edit remark
 
