@@ -47,6 +47,7 @@ class QTextEdit;
 class QToolButton;
 class QButtonGroup;
 class QPopupMenu;
+class QPrinter;
 
 namespace AS {
 
@@ -63,10 +64,10 @@ public:
     QButtonGroup *m_pWeekmonthgroup;
     QToolButton  *m_pWeeklybutt;
     QToolButton  *m_pMonthlybutt;
-    QToolButton  *m_pBothbutt;
     QTextEdit    *m_pBrowser;
     QPushButton  *m_pSavebutt;
     QPushButton  *m_pDismissbutt;
+    QPushButton  *m_pPrintbutt;
 
 protected:
     QVBoxLayout *m_pFormlay;
@@ -82,16 +83,19 @@ private:
     int          m_nMonths;
     TiTable     *m_pReptable;
     Preferences *m_pReprefs;
+#ifndef QT_NO_PRINTER
+    QPrinter    *m_pPrinter;
+#endif
 
 public slots:
     int exec(void);
 
 protected slots:
     virtual void saveReport(void);
+    virtual void printReport(void);
     virtual void textChange(void);
     virtual void reportWeeks(int nMenuid = -1);
     virtual void reportMonths(int nMenuid = -1);
-    virtual void reportBoth(int nMenuid = -1);
 
 private:
     void writeHeader(int);
