@@ -1770,8 +1770,15 @@ void Titraqform::syncSoap(void)
         // Iterate through the selection of row entries to transmit
         for (int nRowiter = 0; nRowiter < nTotal; nRowiter++) {
             QString Syncthis = m_pMaintable->text(Select.topRow() + nRowiter, TITRAQ_IDXUSER);
-            for (int nColiter = TITRAQ_IDXUSER + 1; nColiter < TITRAQ_IDXTAIL; nColiter++)
-                Syncthis += ' ' + m_pMaintable->text(Select.topRow() + nRowiter, nColiter);
+            Syncthis += ' ' + m_pMaintable->text(Select.topRow() + nRowiter, TITRAQ_IDXGUID);
+            Syncthis += ' ' + m_pMaintable->text(Select.topRow() + nRowiter, TITRAQ_IDXCRC).remove("0x");
+            Syncthis += ' ' + m_pMaintable->text(Select.topRow() + nRowiter, TITRAQ_IDXREV);
+            Syncthis += ' ' + m_pMaintable->text(Select.topRow() + nRowiter, TITRAQ_IDXDATE);
+            Syncthis += ' ' + m_pMaintable->text(Select.topRow() + nRowiter, TITRAQ_IDXSTART);
+            Syncthis += ' ' + m_pMaintable->text(Select.topRow() + nRowiter, TITRAQ_IDXFINISH);
+            Syncthis += ' ' + m_pMaintable->text(Select.topRow() + nRowiter, TITRAQ_IDXAMOUNT);
+            Syncthis += ' ' + m_pMaintable->text(Select.topRow() + nRowiter, TITRAQ_IDXTASK);
+            Syncthis += ' ' + ('"' + m_pMaintable->text(Select.topRow() + nRowiter, TITRAQ_IDXREMARK)) + '"';
             Clistr = Syncthis;                          // Build RPC parameter
             Logmeth.AddParameter("Tuple") << Clistr;    // Prepare for marshalling
             const SOAPResponse &Logresp = Proxy.Execute(Logmeth);
@@ -1862,7 +1869,7 @@ void Titraqform::savePrefs(void)
 void Titraqform::helpContents(void)
 {
     try { // Create and execute a new help contents window
-        std::auto_ptr<AS::Helpanel> pHelpcont(new AS::Helpanel(this, "Helpanel"));
+        std::auto_ptr<AS::Helpanel> pHelpcont(new AS::Helpanel(TITRAQ_REFHELP, this, "Helpanel"));
         pHelpcont->exec();
         delete pHelpcont.release(); // Technically unnecessary, smart pointer
     }
@@ -1879,10 +1886,10 @@ void Titraqform::aboutTitraq(void)
 {
     QString Namever = QString(TITRAQ_APPTITLE) + ' ' + asgui_version.v_short;
     QMessageBox *pCwmsg = new QMessageBox(Namever,
-        QObject::trUtf8("AS-GUI is a time and task-based\n"
+        QObject::trUtf8("The as-gui is a time and task-based\n"
                "accounting system that acts as both a\n"
                "work-like punch card and time tracker.\n"
-               "Development of AS-GUI is sponsored by\n"
+               "Development of as-gui is sponsored by\n"
                "Cable & Wireless Deutschland GmbH."),
         QMessageBox::NoIcon, QMessageBox::Ok | QMessageBox::Default,
         QMessageBox::NoButton, QMessageBox::NoButton,
